# Copyright (C) 2021 OpenAnolis Community
#
#
import os
from pyanaconda.ui.categories.software import SoftwareCategory
from pyanaconda.ui.tui.spokes import NormalTUISpoke
from pyanaconda.core.i18n import N_, _, C_

from simpleline.render.containers import ListColumnContainer
from simpleline.render.screen import InputState
from simpleline.render.widgets import TextWidget, CheckboxWidget

from pyanaconda.anaconda_loggers import get_module_logger
log = get_module_logger(__name__)

__all__ = ["BackupRecoverySpoke"]


class BackupRecoverySpoke(NormalTUISpoke):
    """ Spoke used to read new value of text to represent source repo.

       .. inheritance-diagram:: SoftwareSpoke
          :parts: 3
    """
    help_id = "BackupRecoverySelectionSpoke"
    category = SoftwareCategory

    def __init__(self, data, storage, payload):
        super().__init__(data, storage, payload)
        self.title = N_("BackupRecovery selection")
        self._container = None
        self.errors = []
        self.current_BackupRecovery = 1
        self.refresh_backup()

    @property
    def status(self):
        if not self.ready:
            return _("Processing...")

        if self.errors:
            return _("Error checking BackupRecovery selection")
        return self.current_BackupRecovery

    @property
    def completed(self):
        processing_done = self.ready and not self.errors
        return processing_done 
    
    def refresh_backup(self):
        if(self.current_BackupRecovery == 1):
            os.system("touch /tmp/backuped")
        else:
            os.system("rm -rf /tmp/backuped")
        
    def refresh(self, args=None):
        """ Refresh screen. """
        NormalTUISpoke.refresh(self, args)
        self._container = None
        self._container = ListColumnContainer(2, columns_width=38, spacing=2)
        msg = self._refresh_BackupRecoverys()

        self.window.add_with_separator(TextWidget(msg))
        self.window.add_with_separator(self._container)

    def _refresh_BackupRecoverys(self):

        selected = (self.current_BackupRecovery == 1)
        BackupRecovery_desc = _("Enable BackupRecovery")
        BackupRecovery_info = _("Enable BackupRecovery")
        widget = CheckboxWidget(title="%s (%s)" % (1, BackupRecovery_desc), completed=selected)
        self._container.add(widget, callback=self._set_BackupRecovery_callback, data=1)
        
        selected = (self.current_BackupRecovery == 0)
        BackupRecovery_desc = _("Disable BackupRecovery")
        BackupRecovery_info = _("Disable BackupRecovery")
        widget = CheckboxWidget(title="%s (%s)" % (0, BackupRecovery_desc), completed=selected)
        self._container.add(widget, callback=self._set_BackupRecovery_callback, data=0)

        return _("BackupRecovery List")

    def _set_BackupRecovery_callback(self, data):
        self.current_BackupRecovery = data
        self.refresh_backup()

    def input(self, args, key):
        if self._container is not None and self._container.process_user_input(key):
            self.redraw()
        else:
            # TRANSLATORS: 'c' to continue
            if key.lower() == C_('TUI|Spoke Navigation', 'c'):
                self.refresh_backup()
                self.close()
            else:
                return super().input(args, key)

        return InputState.PROCESSED
    
